@@ -57,6 +57,7 @@ MyWidget::~MyWidget()
 {
 }
 
+#ifdef GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
 void MyWidget::on_size_request(Gtk::Requisition* requisition)
 {
   //Initialize the output parameter:
@@ -196,3 +197,4 @@ bool MyWidget::on_expose_event(GdkEventExpose* event)
   }
   return true;
 }
+#endif /* GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED */
